@@ -78,13 +78,16 @@ class RundeckJobs(object):
             vcs_repo_oauth_token_id: str = os.environ.get(
                 'RD_OPTION_VCS_REPO_OAUTH_TOKEN_ID'),
             tag_names: str = os.environ.get('RD_OPTION_TAG_NAMES'),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/terraform/rootmodule/terraform_cloud_workspace",
+            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/terraform_cloud_workspace",
     ):
 
         pg_backend_conn_str = f"postgres://{pg_user}:{pg_password}@{pg_ip}:{pg_port}/{pg_db}"
 
         config_dir_location = f'/tmp/{fqdn}'
-        shutil.rmtree(config_dir_location, ignore_errors=True)
+        if os.path.isdir(config_dir_location):
+            logger.info(f"Removing existing config dir {config_dir_location}")
+            shutil.rmtree(config_dir_location)
+            logger.info(f"Removed existing config dir {config_dir_location}")
 
         backend_config_file_location = f"/tmp/{fqdn}.backend.tfvars"
         backend_config_file_content = f'''conn_str = "{pg_backend_conn_str}"'''
@@ -185,7 +188,7 @@ class RundeckJobs(object):
             jira_issue_key: str = os.environ.get("RD_OPTION_JIRA_ISSUE_KEY"),
             terraform_cloud_token: str = os.environ.get(
                 "RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/terraform/rootmodule/hcloud_web_solutions"
+            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/hcloud_web_solutions"
 
     ):
 
@@ -209,7 +212,10 @@ class RundeckJobs(object):
             path=f'tenant/devops/{project_name}/hetzner')['data']['data']['api_token']
 
         config_dir_location = f'/tmp/{fqdn}'
-        shutil.rmtree(config_dir_location, ignore_errors=True)
+        if os.path.isdir(config_dir_location):
+            logger.info(f"Removing existing config dir {config_dir_location}")
+            shutil.rmtree(config_dir_location)
+            logger.info(f"Removed existing config dir {config_dir_location}")
 
         backend_config_file_location = f"/tmp/{fqdn}.backend.tfvars"
         backend_config_file_content = '''
